@@ -28,7 +28,10 @@ from .data_conversions import (  # noqa: F401
     vaex_dataframe_schema,
 )
 
-from .logging import enable_compliant_logging  # noqa: F401
-from .logging import enable_confidential_logging  # noqa: F401
+from .logging import (  # noqa: F401
+    enable_compliant_logging,
+    enable_confidential_logging,
+    is_eyesoff,
+)
 from .system_info import provide_system_info  # noqa: F401
 from .exceptions import prefix_stack_trace  # noqa: F401
