@@ -277,7 +277,12 @@ def print_prefixed_stack_trace_and_raise(
     """
     if err is None:
         err = sys.exc_info()[1]
-    scrubbed_err = scrub_exception(err, scrub_message, prefix, keep_message, allow_list)
+    scrubbed_err = err
+    if err not in SCRUBBED_EXCEPTIONS:
+        scrubbed_err = scrub_exception(
+            err, scrub_message, prefix, keep_message, allow_list
+        )
+        SCRUBBED_EXCEPTIONS.add(scrubbed_err)
 
     tb_exception = TracebackException.from_exception(scrubbed_err)  # type: ignore
 
@@ -369,7 +374,8 @@ def prefix_stack_trace(
         def foo(x):
             pass
     """
-
+    global SCRUBBED_EXCEPTIONS
+    SCRUBBED_EXCEPTIONS = set()
     return _PrefixStackTraceWrapper(
         file, disable, prefix, scrub_message, keep_message, allow_list, add_timestamp
     )
