@@ -4,7 +4,7 @@
 """ Configuration dataclasses for AMLPipelineHelper """
 from dataclasses import dataclass, field
 from omegaconf import MISSING
-from typing import Optional, Any, Dict
+from typing import Optional, Any, Dict, List, Union
 from shrike.pipeline.module_helper import module_loader_config, module_manifest
 
 # Default config for HDI components
@@ -85,11 +85,35 @@ class pipeline_compute_config:  # pylint: disable=invalid-name
 
 @dataclass
 class tenant_override_config:
+    """Tenant override configuration"""
+
     allow_override: bool = False
     keep_modified_files: bool = False
     mapping: Dict[str, Any] = field(default_factory=lambda: {})
 
 
+@dataclass
+class silo:
+    """Silo info for federated learning"""
+
+    compute: str = MISSING
+    datastore: str = MISSING
+    params: Optional[Dict[str, Any]] = MISSING
+    inherit: Optional[List[str]] = MISSING
+
+
+@dataclass
+class federated_config:
+    """Federated learning configuration"""
+
+    silos: Dict[str, silo] = MISSING
+    max_iterations: int = 1
+    params: Optional[Dict[str, Any]] = MISSING
+    config_group: Optional[Dict[str, Any]] = MISSING
+    data_transfer_component: str = MISSING
+    deactivate_data_transfer: bool = False
+
+
 def default_config_dict():
     """Constructs the config dictionary for the pipeline helper settings"""
     return {
@@ -99,4 +123,5 @@ def default_config_dict():
         "module_loader": module_loader_config,
         "modules": module_manifest,
         "tenant_overrides": tenant_override_config,
+        "federated_config": federated_config,
     }
