@@ -15,6 +15,8 @@ import shutil
 import yaml
 import jsonpath_ng
 from typing import Callable
+from hashlib import sha256
+from pathlib import Path
 
 try:
     import hydra
@@ -44,6 +46,7 @@ from shrike.pipeline.canary_helper import get_repo_info
 from shrike.pipeline.module_helper import AMLModuleLoader
 from shrike.pipeline.pipeline_config import default_config_dict, HDI_DEFAULT_CONF
 from shrike.pipeline.telemetry_utils import TelemetryLogger
+from shrike._core import is_eyesoff_helper
 
 
 log = logging.getLogger(__name__)
@@ -204,6 +207,17 @@ class AMLPipelineHelper:
             )
         return True
 
+    def is_eyesoff(self) -> bool:
+        """ "
+        Check whether the workspace is eyes-off.
+        If it lives in a non-Torus tenant, then eyes-off;
+        If in Torus tenant, check whether it is in the allow-list of eyes-on Torus subscriptions.
+        """
+        workspace = self.workspace()
+        tenant_id = workspace.get_details()["identity"]["tenant_id"]
+        subscription_id = workspace.subscription_id
+        return is_eyesoff_helper(tenant_id, subscription_id)
+
     #######################
     ### HELPER BACKEND  ###
     #######################
@@ -241,18 +255,21 @@ class AMLPipelineHelper:
             input_instance.configure(mode=input_mode)
             log.info(f"Configured input {input_key} to use mode {input_mode}")
 
-    def _set_all_outputs_to(self, module_instance, output_mode, compliant=True):
+    def _set_all_outputs_to(
+        self, module_instance, output_mode, compliant=True, datastore_name=None
+    ):
         """Sets all module outputs to a given output mode"""
         output_names = [
             a
             for a in dir(module_instance.outputs)
             if isinstance(getattr(module_instance.outputs, a), Output)
         ]
-        datastore_name = (
-            self.config.compute.compliant_datastore
-            if compliant
-            else self.config.compute.noncompliant_datastore
-        )
+        if not datastore_name:
+            datastore_name = (
+                self.config.compute.compliant_datastore
+                if compliant
+                else self.config.compute.noncompliant_datastore
+            )
         for output_key in output_names:
             output_instance = getattr(module_instance.outputs, output_key)
             if output_mode is None:
@@ -351,6 +368,7 @@ class AMLPipelineHelper:
         conf=None,
         input_mode=None,
         output_mode=None,
+        datastore_name=None,
         **custom_runtime_arguments,
     ):
         """Applies settings for a HDI module.
@@ -420,7 +438,9 @@ class AMLPipelineHelper:
 
         if input_mode:
             self._set_all_inputs_to(module_instance, input_mode)
-        self._set_all_outputs_to(module_instance, output_mode)
+        self._set_all_outputs_to(
+            module_instance, output_mode, datastore_name=datastore_name
+        )
 
     def _apply_parallel_runsettings(
         self,
@@ -437,6 +457,7 @@ class AMLPipelineHelper:
         error_threshold=None,
         input_mode=None,
         output_mode=None,
+        datastore_name=None,
         **custom_runtime_arguments,
     ):
         """Applies settings for a ParallelRunStep linux module.
@@ -528,7 +549,9 @@ class AMLPipelineHelper:
         if input_mode:
             self._set_all_inputs_to(module_instance, input_mode)
         if output_mode:
-            self._set_all_outputs_to(module_instance, output_mode)
+            self._set_all_outputs_to(
+                module_instance, output_mode, datastore_name=datastore_name
+            )
 
     def _apply_linux_runsettings(
         self,
@@ -541,6 +564,7 @@ class AMLPipelineHelper:
         process_count_per_node=None,
         input_mode=None,
         output_mode=None,
+        datastore_name=None,
         **custom_runtime_arguments,
     ):
         """Applies settings for linux module.
@@ -618,12 +642,15 @@ class AMLPipelineHelper:
             self._set_all_inputs_to(
                 module_instance, self.config.compute.linux_input_mode
             )
-
         if output_mode:
-            self._set_all_outputs_to(module_instance, output_mode)
+            self._set_all_outputs_to(
+                module_instance, output_mode, datastore_name=datastore_name
+            )
         else:
             self._set_all_outputs_to(
-                module_instance, self.config.compute.linux_output_mode
+                module_instance,
+                self.config.compute.linux_output_mode,
+                datastore_name=datastore_name,
             )
 
     def _apply_scope_runsettings(
@@ -673,6 +700,7 @@ class AMLPipelineHelper:
         target=None,
         input_mode=None,
         output_mode=None,
+        datastore_name=None,
         **custom_runtime_arguments,
     ):
         """Applies settings for a HDI module.
@@ -700,7 +728,9 @@ class AMLPipelineHelper:
 
         if input_mode:
             self._set_all_inputs_to(module_instance, input_mode)
-        self._set_all_outputs_to(module_instance, output_mode, compliant)
+        self._set_all_outputs_to(
+            module_instance, output_mode, compliant, datastore_name
+        )
 
     def _apply_sweep_runsettings(
         self,
@@ -725,6 +755,7 @@ class AMLPipelineHelper:
         max_total_trials=None,
         max_concurrent_trials=None,
         timeout_minutes=None,
+        datastore_name=None,
         **custom_runtime_arguments,
     ):
         """Applies settings for a sweep component.
@@ -800,7 +831,9 @@ class AMLPipelineHelper:
         if input_mode:
             self._set_all_inputs_to(module_instance, input_mode)
         if output_mode:
-            self._set_all_outputs_to(module_instance, output_mode)
+            self._set_all_outputs_to(
+                module_instance, output_mode, datastore_name=datastore_name
+            )
 
         if algorithm:
             module_instance.runsettings.sweep.algorithm = algorithm
@@ -849,7 +882,11 @@ class AMLPipelineHelper:
 
     def _check_module_runsettings_consistency(self, module_key, module_instance):
         """Verifies if entry at module_key matches the module instance description"""
-        module_manifest_entry, _ = self.module_loader.get_module_manifest_entry(
+        (
+            module_manifest_entry,
+            _,
+            is_in_manifest,
+        ) = self.module_loader.get_module_manifest_entry(
             module_key, modules_manifest=self.required_modules()
         )
 
@@ -1490,6 +1527,7 @@ class AMLPipelineHelper:
                 if override:
                     log.info("Now trying to recover overrides.")
                 self._recover_tenant_overrides(override, yaml_to_be_recovered, False)
+                raise
             else:
                 self._recover_tenant_overrides(
                     override, yaml_to_be_recovered, keep_modified_files
